function [] = learnKDEN(obj,options)
% Learn the non-parametric local models of the Bayesian network.
%   options: Matlab structure with the following fields:
%               enableAll      : Whether to use approximate log-likelihoods. 
%                                Possible values are {0,1}. Optional field with default 0.
%               totalClusters  : The total number of clusters to use for approximate log-likelihood computations.
%                                Possible values are scalar integers between 1 and samples.
%                                Only relevant if enableAll==1. Optional field with default 50.
% 
% (c)2014 Andreas M. Lehrmann

for i=1:length(obj.ordering)
   lDisp(['Computing a conditional kernel density estimate for variable ' int2str(i) '...'])
   cIndex = obj.ordering(i);
   cData = obj.variables(cIndex).data;
   pIndex = obj.getPa(cIndex);
   [pData{1:length(pIndex),1}] = obj.variables(pIndex).data;
   jData = [cData;cell2mat(pData)];
   
   kde = KDE;
   kde.estimate(jData,size(cData,1)+1:size(jData,1),options);
   if isfield(options,'enableAll')&&isfloat(options.enableAll)
       if options.enableAll
           if isfield(options,'totalClusters')&&isfloat(options.totalClusters) 
                kde.switchAll(1,options.totalClusters);
           else
                kde.switchAll(1,50);
           end
       end           
   end
   obj.variables(cIndex).cpd = kde;
end

end