% General class representing a multivariate Gaussian distribution.
%   mu   : (n,1) double array. Mean of the distribution.
%   sigma: (n,n) symmetric, positive-definite matrix. Covariance matrix of the distribution.
% 
% (c)2014 Andreas M. Lehrmann

classdef Gaussian < handle

    properties
        mu
        sigma
        cond
        
        dim
        llConstant
        precision
    end
    
    methods        
        function obj = Gaussian(mu, sigma)    
           
            if nargin>0
                assert(size(mu,2)==1)
                obj.mu = mu;
                obj.sigma = sigma;

                obj.dim = length(mu);
                obj.precision = inv(sigma);
                obj.llConstant = -sum(log(diag(chol(2*pi*obj.sigma))));
            end
            
        end
    end
end